Module data_management_framework

Module data_management_framework 

Available on crate feature api-12 only.

Structs

OH_UdmfDataLoadInfoapi-20
Indicates data loading information.
OH_UdmfOptionsapi-20
Describes the optional arguments of data operation
OH_Udmf_ProgressInfoapi-15
Represents the udmf progress information.
Udmf_FileConflictOptionsapi-15
Describe the types of file conflict options when getting data from the udmf.
Udmf_Intention
Describe the intention type of the udmf.
Udmf_ProgressIndicatorapi-15
Describe the types of progress indicator when getting data from the udmf.
Udmf_ShareOption
Describe intra-device usage range type enumeration.
Udmf_Visibilityapi-20
Describe the visibility range of data

Constants

UDMF_KEY_BUFFER_LEN

Functions

OH_UDMF_GetDataElementAtapi-22
Gets the pointer to the element at the specified index from the input array.
OH_UdmfDataLoadInfo_Createapi-20
Creation a pointer to the instance of the OH_UdmfDataLoadInfo.
OH_UdmfDataLoadInfo_Destroyapi-20
Destroy the heap memory pointed to by the pointer of OH_UdmfDataLoadInfo. Note that this function cannot be called repeatedly for the same pointer.
OH_UdmfDataLoadInfo_GetRecordCountapi-20
Gets the record count from the OH_UdmfDataLoadInfo.
OH_UdmfDataLoadInfo_GetTypesapi-20
Gets the types from the OH_UdmfDataLoadInfo.
OH_UdmfDataLoadInfo_SetRecordCountapi-20
Sets the record count to the OH_UdmfDataLoadInfo.
OH_UdmfDataLoadInfo_SetTypeapi-20
Sets the data load info to the OH_UdmfDataLoadInfo.
OH_UdmfDataLoadParams_Createapi-20
Creation a pointer to the instance of the OH_UdmfDataLoadParams.
OH_UdmfDataLoadParams_Destroyapi-20
Destroy a pointer that points to an instance of OH_UdmfDataLoadParams.
OH_UdmfDataLoadParams_SetDataLoadInfoapi-20
Sets the data load info to the OH_UdmfDataLoadParams.
OH_UdmfDataLoadParams_SetLoadHandlerapi-20
Sets the data load handler to the OH_UdmfDataLoadParams.
OH_UdmfData_AddRecord
Add one {OH_UdmfRecord} record to the OH_UdmfData data.
OH_UdmfData_Create
Creation a pointer to the instance of the OH_UdmfData.
OH_UdmfData_Destroy
Destroy a pointer that points to the OH_UdmfData instance.
OH_UdmfData_GetPrimaryHtmlapi-13
Get one OH_UdsHtml data from the OH_UdmfData.
OH_UdmfData_GetPrimaryPlainTextapi-13
Get primary OH_UdsPlainText data from the OH_UdmfData.
OH_UdmfData_GetRecordapi-13
Get the record of the specified index from the OH_UdmfData.
OH_UdmfData_GetRecordCountapi-13
Get the count of OH_UdmfRecord in the OH_UdmfData.
OH_UdmfData_GetRecords
Get all records in the OH_UdmfData data.
OH_UdmfData_GetTypes
Get all types in the OH_UdmfData data.
OH_UdmfData_HasType
Check whether the type exists in the OH_UdmfData data.
OH_UdmfData_IsLocalapi-13
Checks whether the UDMF data is from a local device.
OH_UdmfGetDataParams_Createapi-15
Creation a pointer to the instance of the OH_UdmfGetDataParams.
OH_UdmfGetDataParams_Destroyapi-15
Destroy a pointer that points to an instance of OH_UdmfGetDataParams.
OH_UdmfGetDataParams_SetAcceptableInfoapi-20
Sets the acceptable info to the OH_UdmfGetDataParams.
OH_UdmfGetDataParams_SetDataProgressListenerapi-15
Sets the progress indicator to the OH_UdmfGetDataParams.
OH_UdmfGetDataParams_SetDestUriapi-15
Sets the destination uri to the OH_UdmfGetDataParams.
OH_UdmfGetDataParams_SetFileConflictOptionsapi-15
Sets the file conflict options to the OH_UdmfGetDataParams.
OH_UdmfGetDataParams_SetProgressIndicatorapi-15
Sets the progress indicator to the OH_UdmfGetDataParams.
OH_UdmfOptions_Createapi-20
Creation a pointer to the instance of the OH_UdmfOptions.
OH_UdmfOptions_Destroyapi-20
Destroy the heap memory pointed to by the pointer of OH_UdmfOptions. Note that this function cannot be called repeatedly for the same pointer.
OH_UdmfOptions_GetIntentionapi-20
Get intention from the OH_UdmfOptions.
OH_UdmfOptions_GetKeyapi-20
Get key from the OH_UdmfOptions.
OH_UdmfOptions_GetVisibilityapi-20
Get visibility from the OH_UdmfOptions.
OH_UdmfOptions_Resetapi-20
Reset OH_UdmfOptions to default.
OH_UdmfOptions_SetIntentionapi-20
Set intention value to OH_UdmfOptions.
OH_UdmfOptions_SetKeyapi-20
Set the key to the OH_UdmfOptions.
OH_UdmfOptions_SetVisibilityapi-20
Set visibility value to OH_UdmfOptions.
OH_UdmfProgressInfo_GetProgressapi-15
Gets the progress from the OH_Udmf_ProgressInfo.
OH_UdmfProgressInfo_GetStatusapi-15
Gets the status from the OH_Udmf_ProgressInfo.
OH_UdmfProperty_Create
Creation a pointer to the instance of the OH_UdmfProperty from a OH_UdmfData data.
OH_UdmfProperty_Destroy
Destroy a pointer that points to the OH_UdmfProperty instance.
OH_UdmfProperty_GetExtrasIntParam
Get integer value by key from the OH_UdmfProperty.
OH_UdmfProperty_GetExtrasStringParam
Get tag value from the OH_UdmfProperty.
OH_UdmfProperty_GetShareOption
Get share option value from the OH_UdmfProperty.
OH_UdmfProperty_GetTag
Get tag value from the OH_UdmfProperty.
OH_UdmfProperty_GetTimestamp
Get timestamp value from the OH_UdmfProperty.
OH_UdmfProperty_SetExtrasIntParam
Set extras param to OH_UdmfProperty.
OH_UdmfProperty_SetExtrasStringParam
Set extras param to OH_UdmfProperty.
OH_UdmfProperty_SetShareOption
Set Udmf_ShareOption value to OH_UdmfProperty.
OH_UdmfProperty_SetTag
Set tag value to OH_UdmfProperty .
OH_UdmfRecordProvider_Createapi-13
Creates an OH_UdmfRecordProvider instance.
OH_UdmfRecordProvider_Destroyapi-13
Destroy an OH_UdmfRecordProvider instance.
OH_UdmfRecordProvider_SetDataapi-13
Sets a callback function to obtain data.
OH_UdmfRecord_AddAppItem
Add one {OH_UdsAppItem} data to the OH_UdmfRecord record.
OH_UdmfRecord_AddArrayBufferapi-13
Add one OH_UdsArrayBuffer data to the OH_UdmfRecord record.
OH_UdmfRecord_AddContentFormapi-14
Add one OH_UdsContentForm data to the OH_UdmfRecord record.
OH_UdmfRecord_AddFileUriapi-13
Add one {OH_UdsFileUri} data to the OH_UdmfRecord record.
OH_UdmfRecord_AddGeneralEntry
Add one custom data to the OH_UdmfRecord record.
OH_UdmfRecord_AddHtml
Add one {OH_UdsHtml} data to the OH_UdmfRecord record.
OH_UdmfRecord_AddHyperlink
Add one {OH_UdsHyperlink} data to the OH_UdmfRecord record.
OH_UdmfRecord_AddPixelMapapi-13
Add one {OH_UdsPixelMap} data to the OH_UdmfRecord record.
OH_UdmfRecord_AddPlainText
Add one {OH_UdsPlainText} data to the OH_UdmfRecord record.
OH_UdmfRecord_Create
Creation a pointer to the instance of the OH_UdmfRecord, it’s relate with UDS data.
OH_UdmfRecord_Destroy
Destroy a pointer that points to an instance of OH_UdmfRecord.
OH_UdmfRecord_GetAppItem
Get one {OH_UdsAppItem} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetArrayBufferapi-13
Get one OH_UdsArrayBuffer data from the OH_UdmfRecord record.
OH_UdmfRecord_GetContentFormapi-14
Get one OH_UdsContentForm data from the OH_UdmfRecord record.
OH_UdmfRecord_GetFileUriapi-13
Get one {OH_UdsFileUri} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetGeneralEntry
Get one entry data from the OH_UdmfRecord record.
OH_UdmfRecord_GetHtml
Get one {OH_UdsHtml} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetHyperlink
Get one {OH_UdsHyperlink} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetPixelMapapi-13
Get one {OH_UdsPixelMap} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetPlainText
Get one {OH_UdsPlainText} data from the OH_UdmfRecord record.
OH_UdmfRecord_GetTypes
Get all types in the OH_UdmfRecord record.
OH_UdmfRecord_SetProviderapi-13
Set the data provider of the types.
OH_Udmf_DeleteUnifiedDataapi-20
Delete OH_UdmfData data of database with options.
OH_Udmf_DestroyDataArrayapi-20
Destroy data array memory.
OH_Udmf_GetUnifiedData
Get OH_UdmfData data from udmf database.
OH_Udmf_GetUnifiedDataByOptionsapi-20
Get OH_UdmfData data array from udmf database by intention.
OH_Udmf_SetUnifiedData
Set OH_UdmfData data to database.
OH_Udmf_SetUnifiedDataByOptionsapi-20
Set OH_UdmfData data to database with options.
OH_Udmf_UpdateUnifiedDataapi-20
Update OH_UdmfData data to database with options.

Type Aliases

OH_UdmfRecordProvider_GetDataapi-13
Defines a callback function used to obtain data by type.
OH_Udmf_DataLoadHandlerapi-20
Indicates the callback function for loading data.
OH_Udmf_DataProgressListenerapi-15
Defines the callback function used to return the progress information and data.
UdmfData_Finalizeapi-13
Defines the callback function used free the context.