OH_UDMF_GetDataElementAt

Function OH_UDMF_GetDataElementAt 

pub unsafe extern "C" fn OH_UDMF_GetDataElementAt(
    dataArray: *mut *mut OH_UdmfData,
    index: c_uint,
) -> *mut OH_UdmfData
Available on crate feature api-22 only.
Gets the pointer to the element at the specified index from the input array.

Arguments

  • dataArray - A pointer to an array of OH_UdmfData pointers.

  • index - The index of the desired element. Note that the input index should not exceed the array range.

Returns

  • A pointer to the OH_UdmfData element at the specified index; returns NULL if the array is NULL. OH_UdmfData Available since API-level: 22