#[repr(transparent)]pub struct Udmf_ShareOption(pub c_uint);Available on crate feature
api-12 only.Expand description
Describe intra-device usage range type enumeration.
Available since API-level: 12
Tuple Fields
0: c_uintImplementations
Sourcepub const INVALID: Udmf_ShareOption
pub const INVALID: Udmf_ShareOption
Invalid share option.
Sourcepub const IN_APP: Udmf_ShareOption
pub const IN_APP: Udmf_ShareOption
Allowed to be used in the same application on this device.
Sourcepub const CROSS_APP: Udmf_ShareOption
pub const CROSS_APP: Udmf_ShareOption
Allowed to be used in the cross application on this device.