OH_UdsContentForm_Create

Function OH_UdsContentForm_Create 

pub unsafe extern "C" fn OH_UdsContentForm_Create() -> *mut OH_UdsContentForm
Available on crate feature api-14 only.
Creation a pointer to the instance of the OH_UdsContentForm.

Returns

  • If the operation is successful, a pointer to the instance of the OH_UdsContentForm structure is returned. If the operation is failed, nullptr is returned. OH_UdsContentForm Available since API-level: 14