OH_UdsFileUri_Create

Function OH_UdsFileUri_Create 

pub unsafe extern "C" fn OH_UdsFileUri_Create() -> *mut OH_UdsFileUri
Available on crate feature api-13 only.
Creation a pointer to the instance of the OH_UdsFileUri.

Returns

  • If the operation is successful, a pointer to the instance of the OH_UdsFileUri structure is returned. If the memory is not enough, nullptr is returned. OH_UdsFileUri Available since API-level: 13