OH_UdsPixelMap_Create

Function OH_UdsPixelMap_Create 

pub unsafe extern "C" fn OH_UdsPixelMap_Create() -> *mut OH_UdsPixelMap
Available on crate feature api-13 only.
Creation a pointer to the instance of the OH_UdsPixelMap.

Returns

  • If the operation is successful, a pointer to the instance of the OH_UdsPixelMap structure is returned. If the memory is not enough, nullptr is returned. OH_UdsPixelMap Available since API-level: 13