Available on crate feature
api-12 only.Structs
- OH_
Udmf Data Load Info api-20 - Indicates data loading information.
- OH_
Udmf Options api-20 - Describes the optional arguments of data operation
- OH_
Udmf_ Progress Info api-15 - Represents the udmf progress information.
- Udmf_
File Conflict Options api-15 - Describe the types of file conflict options when getting data from the udmf.
- Udmf_
Intention - Describe the intention type of the udmf.
- Udmf_
Progress Indicator api-15 - Describe the types of progress indicator when getting data from the udmf.
- Udmf_
Share Option - Describe intra-device usage range type enumeration.
- Udmf_
Visibility api-20 - Describe the visibility range of data
Constants
Functions
- OH_
UDMF_ ⚠GetData Element At api-22 - Gets the pointer to the element at the specified index from the input array.
- OH_
Udmf ⚠Data Load Info_ Create api-20 - Creation a pointer to the instance of the
OH_UdmfDataLoadInfo. - OH_
Udmf ⚠Data Load Info_ Destroy api-20 - Destroy the heap memory pointed to by the pointer of
OH_UdmfDataLoadInfo. Note that this function cannot be called repeatedly for the same pointer. - OH_
Udmf ⚠Data Load Info_ GetRecord Count api-20 - Gets the record count from the
OH_UdmfDataLoadInfo. - OH_
Udmf ⚠Data Load Info_ GetTypes api-20 - Gets the types from the
OH_UdmfDataLoadInfo. - OH_
Udmf ⚠Data Load Info_ SetRecord Count api-20 - Sets the record count to the
OH_UdmfDataLoadInfo. - OH_
Udmf ⚠Data Load Info_ SetType api-20 - Sets the data load info to the
OH_UdmfDataLoadInfo. - OH_
Udmf ⚠Data Load Params_ Create api-20 - Creation a pointer to the instance of the
OH_UdmfDataLoadParams. - OH_
Udmf ⚠Data Load Params_ Destroy api-20 - Destroy a pointer that points to an instance of
OH_UdmfDataLoadParams. - OH_
Udmf ⚠Data Load Params_ SetData Load Info api-20 - Sets the data load info to the
OH_UdmfDataLoadParams. - OH_
Udmf ⚠Data Load Params_ SetLoad Handler api-20 - Sets the data load handler to the
OH_UdmfDataLoadParams. - OH_
Udmf ⚠Data_ AddRecord - Add one {OH_UdmfRecord} record to the
OH_UdmfDatadata. - OH_
Udmf ⚠Data_ Create - Creation a pointer to the instance of the
OH_UdmfData. - OH_
Udmf ⚠Data_ Destroy - Destroy a pointer that points to the
OH_UdmfDatainstance. - OH_
Udmf ⚠Data_ GetPrimary Html api-13 - Get one
OH_UdsHtmldata from theOH_UdmfData. - OH_
Udmf ⚠Data_ GetPrimary Plain Text api-13 - Get primary
OH_UdsPlainTextdata from theOH_UdmfData. - OH_
Udmf ⚠Data_ GetRecord api-13 - Get the record of the specified index from the
OH_UdmfData. - OH_
Udmf ⚠Data_ GetRecord Count api-13 - Get the count of
OH_UdmfRecordin theOH_UdmfData. - OH_
Udmf ⚠Data_ GetRecords - Get all records in the
OH_UdmfDatadata. - OH_
Udmf ⚠Data_ GetTypes - Get all types in the
OH_UdmfDatadata. - OH_
Udmf ⚠Data_ HasType - Check whether the type exists in the
OH_UdmfDatadata. - OH_
Udmf ⚠Data_ IsLocal api-13 - Checks whether the UDMF data is from a local device.
- OH_
Udmf ⚠GetData Params_ Create api-15 - Creation a pointer to the instance of the
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ Destroy api-15 - Destroy a pointer that points to an instance of
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ SetAcceptable Info api-20 - Sets the acceptable info to the
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ SetData Progress Listener api-15 - Sets the progress indicator to the
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ SetDest Uri api-15 - Sets the destination uri to the
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ SetFile Conflict Options api-15 - Sets the file conflict options to the
OH_UdmfGetDataParams. - OH_
Udmf ⚠GetData Params_ SetProgress Indicator api-15 - Sets the progress indicator to the
OH_UdmfGetDataParams. - OH_
Udmf ⚠Options_ Create api-20 - Creation a pointer to the instance of the
OH_UdmfOptions. - OH_
Udmf ⚠Options_ Destroy api-20 - Destroy the heap memory pointed to by the pointer of
OH_UdmfOptions. Note that this function cannot be called repeatedly for the same pointer. - OH_
Udmf ⚠Options_ GetIntention api-20 - Get intention from the
OH_UdmfOptions. - OH_
Udmf ⚠Options_ GetKey api-20 - Get key from the
OH_UdmfOptions. - OH_
Udmf ⚠Options_ GetVisibility api-20 - Get visibility from the
OH_UdmfOptions. - OH_
Udmf ⚠Options_ Reset api-20 - Reset
OH_UdmfOptionsto default. - OH_
Udmf ⚠Options_ SetIntention api-20 - Set intention value to
OH_UdmfOptions. - OH_
Udmf ⚠Options_ SetKey api-20 - Set the key to the
OH_UdmfOptions. - OH_
Udmf ⚠Options_ SetVisibility api-20 - Set visibility value to
OH_UdmfOptions. - OH_
Udmf ⚠Progress Info_ GetProgress api-15 - Gets the progress from the
OH_Udmf_ProgressInfo. - OH_
Udmf ⚠Progress Info_ GetStatus api-15 - Gets the status from the
OH_Udmf_ProgressInfo. - OH_
Udmf ⚠Property_ Create - Creation a pointer to the instance of the
OH_UdmfPropertyfrom aOH_UdmfDatadata. - OH_
Udmf ⚠Property_ Destroy - Destroy a pointer that points to the
OH_UdmfPropertyinstance. - OH_
Udmf ⚠Property_ GetExtras IntParam - Get integer value by key from the
OH_UdmfProperty. - OH_
Udmf ⚠Property_ GetExtras String Param - Get tag value from the
OH_UdmfProperty. - OH_
Udmf ⚠Property_ GetShare Option - Get share option value from the
OH_UdmfProperty. - OH_
Udmf ⚠Property_ GetTag - Get tag value from the
OH_UdmfProperty. - OH_
Udmf ⚠Property_ GetTimestamp - Get timestamp value from the
OH_UdmfProperty. - OH_
Udmf ⚠Property_ SetExtras IntParam - Set extras param to
OH_UdmfProperty. - OH_
Udmf ⚠Property_ SetExtras String Param - Set extras param to
OH_UdmfProperty. - OH_
Udmf ⚠Property_ SetShare Option - Set Udmf_ShareOption value to
OH_UdmfProperty. - OH_
Udmf ⚠Property_ SetTag - Set tag value to
OH_UdmfProperty. - OH_
Udmf ⚠Record Provider_ Create api-13 - Creates an
OH_UdmfRecordProviderinstance. - OH_
Udmf ⚠Record Provider_ Destroy api-13 - Destroy an
OH_UdmfRecordProviderinstance. - OH_
Udmf ⚠Record Provider_ SetData api-13 - Sets a callback function to obtain data.
- OH_
Udmf ⚠Record_ AddApp Item - Add one {OH_UdsAppItem} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddArray Buffer api-13 - Add one
OH_UdsArrayBufferdata to theOH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddContent Form api-14 - Add one
OH_UdsContentFormdata to theOH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddFile Uri api-13 - Add one {OH_UdsFileUri} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddGeneral Entry - Add one custom data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddHtml - Add one {OH_UdsHtml} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddHyperlink - Add one {OH_UdsHyperlink} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddPixel Map api-13 - Add one {OH_UdsPixelMap} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ AddPlain Text - Add one {OH_UdsPlainText} data to the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ Create - Creation a pointer to the instance of the
OH_UdmfRecord, it’s relate with UDS data. - OH_
Udmf ⚠Record_ Destroy - Destroy a pointer that points to an instance of
OH_UdmfRecord. - OH_
Udmf ⚠Record_ GetApp Item - Get one {OH_UdsAppItem} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetArray Buffer api-13 - Get one
OH_UdsArrayBufferdata from theOH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetContent Form api-14 - Get one
OH_UdsContentFormdata from theOH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetFile Uri api-13 - Get one {OH_UdsFileUri} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetGeneral Entry - Get one entry data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetHtml - Get one {OH_UdsHtml} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetHyperlink - Get one {OH_UdsHyperlink} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetPixel Map api-13 - Get one {OH_UdsPixelMap} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetPlain Text - Get one {OH_UdsPlainText} data from the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ GetTypes - Get all types in the
OH_UdmfRecordrecord. - OH_
Udmf ⚠Record_ SetProvider api-13 - Set the data provider of the types.
- OH_
Udmf_ ⚠Delete Unified Data api-20 - Delete
OH_UdmfDatadata of database with options. - OH_
Udmf_ ⚠Destroy Data Array api-20 - Destroy data array memory.
- OH_
Udmf_ ⚠GetUnified Data - Get
OH_UdmfDatadata from udmf database. - OH_
Udmf_ ⚠GetUnified Data ByOptions api-20 - Get
OH_UdmfDatadata array from udmf database by intention. - OH_
Udmf_ ⚠SetUnified Data - Set
OH_UdmfDatadata to database. - OH_
Udmf_ ⚠SetUnified Data ByOptions api-20 - Set
OH_UdmfDatadata to database with options. - OH_
Udmf_ ⚠Update Unified Data api-20 - Update
OH_UdmfDatadata to database with options.
Type Aliases
- OH_
Udmf Record Provider_ GetData api-13 - Defines a callback function used to obtain data by type.
- OH_
Udmf_ Data Load Handler api-20 - Indicates the callback function for loading data.
- OH_
Udmf_ Data Progress Listener api-15 - Defines the callback function used to return the progress information and data.
- Udmf
Data_ Finalize api-13 - Defines the callback function used free the context.