pub unsafe extern "C" fn OH_UdsContentForm_Create() -> *mut OH_UdsContentFormAvailable on crate feature
api-14 only.Expand description
Creation a pointer to the instance of the OH_UdsContentForm.
Returns
- If the operation is successful, a pointer to the instance of the
OH_UdsContentFormstructure is returned. If the operation is failed, nullptr is returned.OH_UdsContentFormAvailable since API-level: 14