pub unsafe extern "C" fn OH_UdsFileUri_Create() -> *mut OH_UdsFileUriAvailable on crate feature
api-13 only.Expand description
Creation a pointer to the instance of the OH_UdsFileUri.
Returns
- If the operation is successful, a pointer to the instance of the
OH_UdsFileUristructure is returned. If the memory is not enough, nullptr is returned.OH_UdsFileUriAvailable since API-level: 13