pub unsafe extern "C" fn OH_UdsPixelMap_Create() -> *mut OH_UdsPixelMapAvailable on crate feature
api-13 only.Expand description
Creation a pointer to the instance of the OH_UdsPixelMap.
Returns
- If the operation is successful, a pointer to the instance of the
OH_UdsPixelMapstructure is returned. If the memory is not enough, nullptr is returned.OH_UdsPixelMapAvailable since API-level: 13